@@ -44,12 +44,6 @@ impl<T: Type> ParseError<T> {
         Self::new(format!(r#"Type "{}" expects an input value."#, T::name()))
     }
 
-    /// This type does not support parsing from parameter.
-    #[must_use]
-    pub fn not_support_parsing_from_parameter() -> Self {
-        Self::custom("not support parsing from parameter")
-    }
-
     /// A custom error message.
     ///
     /// Any type that implements `Display` is automatically converted to this if
